@@ -40,27 +40,19 @@ except ImportError:
 from ..utils.strtypes import b
 
 
-_random_ports = set()
-
 def select_random_ports(n):
-    """Selects and return n random ports that are available."""
+    """Select and return n random ports that are available."""
     ports = []
+    sockets = []
     for i in range(n):
         sock = socket.socket()
         sock.bind(('', 0))
-        while sock.getsockname()[1] in _random_ports:
-            sock.close()
-            sock = socket.socket()
-            sock.bind(('', 0))
-        ports.append(sock)
-    for i, sock in enumerate(ports):
-        port = sock.getsockname()[1]
+        ports.append(sock.getsockname()[1])
+        sockets.append(sock)
+    for sock in sockets:
         sock.close()
-        ports[i] = port
-        _random_ports.add(port)
     return ports
 
-
 #-----------------------------------------------------------------------------
 # Check for passwordless login
 #-----------------------------------------------------------------------------
@@ -111,7 +103,7 @@ def _try_passwordless_openssh(server, keyfile):
 def _try_passwordless_paramiko(server, keyfile):
     """Try passwordless login with paramiko."""
     if paramiko is None:
-        msg = "Paramiko unavaliable, "
+        msg = "Paramiko unavailable, "
         if sys.platform == 'win32':
             msg += "Paramiko is required for ssh tunneled connections on Windows."
         else:
